@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Campo_Grande"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Campo_Grande", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Campo_Grande", { abbr: true }),
+
 	"1914" : helpers.makeTestYear("America/Campo_Grande", [
 		["1914-01-01T03:38:27+00:00", "23:59:59", "LMT", 13108 / 60],
 		["1914-01-01T03:38:28+00:00", "23:38:28", "-04", 240]
