@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Caracas"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Caracas", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Caracas", { abbr: true }),
+
 	"1912" : helpers.makeTestYear("America/Caracas", [
 		["1912-02-12T04:27:39+00:00", "23:59:59", "CMT", 16060 / 60],
 		["1912-02-12T04:27:40+00:00", "23:57:40", "-0430", 270]
