@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Punta_Arenas"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Punta_Arenas", { offset: true, expect: "Antarctica/Palmer" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Punta_Arenas", { abbr: true, expect: "Antarctica/Palmer" }),
+
 	"1910" : helpers.makeTestYear("America/Punta_Arenas", [
 		["1910-01-10T04:42:45+00:00", "23:59:59", "SMT", 16966 / 60],
 		["1910-01-10T04:42:46+00:00", "23:42:46", "-05", 300]
