@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Santiago"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Santiago", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Santiago", { abbr: true }),
+
 	"1910" : helpers.makeTestYear("America/Santiago", [
 		["1910-01-10T04:42:45+00:00", "23:59:59", "SMT", 16966 / 60],
 		["1910-01-10T04:42:46+00:00", "23:42:46", "-05", 300]
