@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Barnaul"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Barnaul", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Barnaul", { abbr: true }),
+
 	"1919" : helpers.makeTestYear("Asia/Barnaul", [
 		["1919-12-09T18:24:59+00:00", "23:59:59", "LMT", -335],
 		["1919-12-09T18:25:00+00:00", "00:25:00", "+06", -360]
