@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Hong_Kong"] = {
-	"guess" : helpers.makeTestGuess("Asia/Hong_Kong", { offset: false, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Hong_Kong", { offset: true, expect: "Asia/Manila" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Hong_Kong", { abbr: true }),
 
 	"1904" : helpers.makeTestYear("Asia/Hong_Kong", [
 		["1904-10-29T16:23:17+00:00", "23:59:59", "LMT", -27402 / 60],
