@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Hovd"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Hovd", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Hovd", { abbr: true }),
+
 	"1905" : helpers.makeTestYear("Asia/Hovd", [
 		["1905-07-31T17:53:23+00:00", "23:59:59", "LMT", -21996 / 60],
 		["1905-07-31T17:53:24+00:00", "23:53:24", "+06", -360]
