@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Jerusalem"] = {
-	"guess" : helpers.makeTestGuess("Asia/Jerusalem", { offset: false, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Jerusalem", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Jerusalem", { abbr: true }),
 
 	"1917" : helpers.makeTestYear("Asia/Jerusalem", [
 		["1917-12-31T21:39:19+00:00", "23:59:59", "JMT", -8440 / 60],
