@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Asia/Manila"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Asia/Manila", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Asia/Manila", { abbr: true }),
+
 	"1936" : helpers.makeTestYear("Asia/Manila", [
 		["1936-10-31T15:59:59+00:00", "23:59:59", "+08", -480],
 		["1936-10-31T16:00:00+00:00", "01:00:00", "+09", -540]
