@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Europe/Saratov"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Europe/Saratov", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Europe/Saratov", { abbr: true }),
+
 	"1919" : helpers.makeTestYear("Europe/Saratov", [
 		["1919-06-30T23:59:59+00:00", "03:04:17", "LMT", -11058 / 60],
 		["1919-07-01T00:00:00+00:00", "03:00:00", "+03", -180]
