@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Pacific/Easter"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Pacific/Easter", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Easter", { abbr: true }),
+
 	"1932" : helpers.makeTestYear("Pacific/Easter", [
 		["1932-09-01T07:17:27+00:00", "23:59:59", "EMT", 26248 / 60],
 		["1932-09-01T07:17:28+00:00", "00:17:28", "-07", 420]
