@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Pacific/Fiji"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Pacific/Fiji", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Fiji", { abbr: true }),
+
 	"1915" : helpers.makeTestYear("Pacific/Fiji", [
 		["1915-10-25T12:04:15+00:00", "23:59:59", "LMT", -42944 / 60],
 		["1915-10-25T12:04:16+00:00", "00:04:16", "+12", -720]
