@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Pacific/Nauru"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Pacific/Nauru", { offset: true, expect: "Asia/Kamchatka" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Nauru", { abbr: true, expect: "Asia/Kamchatka" }),
+
 	"1921" : helpers.makeTestYear("Pacific/Nauru", [
 		["1921-01-14T12:52:19+00:00", "23:59:59", "LMT", -40060 / 60],
 		["1921-01-14T12:52:20+00:00", "00:22:20", "+1130", -690]
