@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Pacific/Norfolk"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Pacific/Norfolk", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Norfolk", { abbr: true }),
+
 	"1950" : helpers.makeTestYear("Pacific/Norfolk", [
 		["1950-12-31T12:47:59+00:00", "23:59:59", "+1112", -672],
 		["1950-12-31T12:48:00+00:00", "00:18:00", "+1130", -690]
