@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Pacific/Noumea"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Pacific/Noumea", { offset: true, expect: "Pacific/Norfolk" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Noumea", { abbr: true, expect: "Pacific/Norfolk" }),
+
 	"1912" : helpers.makeTestYear("Pacific/Noumea", [
 		["1912-01-12T12:54:11+00:00", "23:59:59", "LMT", -39948 / 60],
 		["1912-01-12T12:54:12+00:00", "23:54:12", "+11", -660]
